@@ -3,20 +3,24 @@ import logging
 from collections import defaultdict
 from typing import Union, List
 
-from peek_plugin_graphdb._private.tuples.GraphDbPackedSegmentTuple import \
-    GraphDbPackedSegmentTuple
+from peek_plugin_graphdb._private.tuples.GraphDbPackedSegmentTuple import (
+    GraphDbPackedSegmentTuple,
+)
 from twisted.internet.defer import Deferred
 from vortex.DeferUtil import deferToThreadWrapWithLogger
 from vortex.Payload import Payload
 from vortex.TupleSelector import TupleSelector
 from vortex.handler.TupleDataObservableHandler import TuplesProviderABC
 
-from peek_plugin_graphdb._private.client.controller.SegmentCacheController import \
-    SegmentCacheController
-from peek_plugin_graphdb._private.tuples.GraphDbEncodedChunkTuple import \
-    GraphDbEncodedChunkTuple
-from peek_plugin_graphdb._private.worker.tasks._SegmentIndexCalcChunkKey import \
-    makeChunkKeyForSegmentKey
+from peek_plugin_graphdb._private.client.controller.SegmentCacheController import (
+    SegmentCacheController,
+)
+from peek_plugin_graphdb._private.tuples.GraphDbEncodedChunkTuple import (
+    GraphDbEncodedChunkTuple,
+)
+from peek_plugin_graphdb._private.worker.tasks._SegmentIndexCalcChunkKey import (
+    makeChunkKeyForSegmentKey,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -26,8 +30,9 @@ class PackedSegmentTupleProvider(TuplesProviderABC):
         self._cacheController = cacheController
 
     @deferToThreadWrapWithLogger(logger)
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
         modelSetKey = tupleSelector.selector["modelSetKey"]
         keys = tupleSelector.selector["keys"]
 
@@ -39,10 +44,14 @@ class PackedSegmentTupleProvider(TuplesProviderABC):
             keysByChunkKey[makeChunkKeyForSegmentKey(modelSetKey, key)].append(key)
 
         for chunkKey, subKeys in keysByChunkKey.items():
-            chunk: GraphDbEncodedChunkTuple = self._cacheController.encodedChunk(chunkKey)
+            chunk: GraphDbEncodedChunkTuple = self._cacheController.encodedChunk(
+                chunkKey
+            )
 
             if not chunk:
-                logger.warning("GraphDb segment chunk %s is missing from cache", chunkKey)
+                logger.warning(
+                    "GraphDb segment chunk %s is missing from cache", chunkKey
+                )
                 continue
 
             segmentsByKeyStr = Payload().fromEncodedPayload(chunk.encodedData).tuples[0]
@@ -52,15 +61,17 @@ class PackedSegmentTupleProvider(TuplesProviderABC):
                 if subKey not in segmentsByKey:
                     logger.warning(
                         "Document %s is missing from index, chunkKey %s",
-                        subKey, chunkKey
+                        subKey,
+                        chunkKey,
                     )
                     continue
 
                 # Create the new object
-                foundDocuments.append(GraphDbPackedSegmentTuple(
-                    key=subKey,
-                    packedJson=segmentsByKey[subKey]
-                ))
+                foundDocuments.append(
+                    GraphDbPackedSegmentTuple(
+                        key=subKey, packedJson=segmentsByKey[subKey]
+                    )
+                )
 
         # Create the vortex message
         return Payload(filt, tuples=foundDocuments).makePayloadEnvelope().toVortexMsg()
